@@ -1,18 +1,20 @@
-"""
+"""Funtions for modifying, loading and saving ONE and Alyx database parameters
 Scenarios:
     - Load ONE with a cache dir: tries to load the Web client params from the dir
-    - Load ONE with http address - gets cache dir from the address?
+    - Load ONE with http address - gets cache dir from the URL map
 
 The ONE params comprise two files: a caches file that contains a map of Alyx db URLs to cache
 directories, and a separate parameter file for each url containing the client parameters.  The
 caches file also sets the default client for when no url is provided.
 
 TODO Rename 'client' kwarg
+FIXME Remove redundant cache_dir param (use directory from client map instead)
 """
 import re
 from iblutil.io import params as iopar
 from getpass import getpass
 from pathlib import Path
+from urllib.parse import urlsplit
 import unicodedata
 
 _PAR_ID_STR = 'one'
@@ -26,7 +28,7 @@ def default():
            "ALYX_PWD": "international",
            "ALYX_URL": "https://openalyx.internationalbrainlab.org",
            "HTTP_DATA_SERVER": "https://ibl.flatironinstitute.org",
-           "HTTP_DATA_SERVER_LOGIN": "iblmember",
+           "HTTP_DATA_SERVER_LOGIN": None,
            "HTTP_DATA_SERVER_PWD": None,
            }
     return iopar.from_dict(par)
@@ -65,6 +67,7 @@ def setup(client=None, silent=False, make_default=None):
     # If a client URL has been provided, set it as the default URL
     par_default = par_default.set('ALYX_URL', client or par_default.ALYX_URL)
     par_current = iopar.read(f'{_PAR_ID_STR}/{client_key}', par_default)
+
     # Load the db URL map
     cache_map = iopar.read(f'{_PAR_ID_STR}/{_CLIENT_ID_STR}', {'CLIENT_MAP': dict()})
     cache_dir = cache_map.CLIENT_MAP.get(client_key, Path(CACHE_DIR_DEFAULT, client_key))
@@ -127,7 +130,7 @@ def get(silent=False, client=None):
     cache_map = iopar.read(f'{_PAR_ID_STR}/{_CLIENT_ID_STR}', {})
     if not cache_map:  # This can be removed in the future
         cache_map = _patch_params()
-    # If there are no
+    # If there are no params for this client, run setup routine
     if not cache_map or (client_key and client_key not in cache_map.CLIENT_MAP):
         cache_map = setup(client=client, silent=silent)
     cache = cache_map.CLIENT_MAP[client_key or cache_map.DEFAULT]
@@ -135,10 +138,13 @@ def get(silent=False, client=None):
 
 
 def save(par, client):
+    # Remove cache dir variable before saving
+    par = {k: v for k, v in par.as_dict().items() if 'CACHE_DIR' not in k}
     iopar.write(f'{_PAR_ID_STR}/{_key_from_url(client)}', par)
 
 
 def get_cache_dir() -> Path:
+    # TODO Add client param
     cache_map = iopar.read(f'{_PAR_ID_STR}/{_CLIENT_ID_STR}', {})
     cache_dir = Path(cache_map.CLIENT_MAP[cache_map.DEFAULT] if cache_map else CACHE_DIR_DEFAULT)
     cache_dir.mkdir(exist_ok=True, parents=True)
@@ -146,7 +152,27 @@ def get_cache_dir() -> Path:
 
 
 def get_params_dir() -> Path:
-    return iopar.getfile(_PAR_ID_STR)
+    return Path(iopar.getfile(_PAR_ID_STR))
+
+
+def get_rest_dir(client=None) -> Path:
+    """Return path to REST cache directory
+
+    Parameters
+    ----------
+    client : str
+        Location of rest cache for a given database URL.  If None, the root REST cache directory is
+        returned
+
+    Returns
+    -------
+        The REST cache directory path
+    """
+    rest_dir = get_params_dir() / '.rest'
+    if client:
+        scheme, loc, *_ = urlsplit(client)
+        rest_dir /= Path(loc, scheme)
+    return rest_dir
 
 
 def _check_cache_conflict(cache_dir):
