@@ -43,7 +43,7 @@ def ses2records(ses: dict) -> [pd.Series, pd.DataFrame]:
         rec = dict(file_size=d['file_size'], hash=d['hash'], exists=True)
         rec['id_0'], rec['id_1'] = parquet.str2np(d['id']).flatten().tolist()
         rec['eid_0'], rec['eid_1'] = session.name
-        file_path = urllib.parse.urlsplit(d['data_url']).path.strip('/')
+        file_path = urllib.parse.urlsplit(d['data_url'], allow_fragments=False).path.strip('/')
         file_path = alfio.remove_uuid_file(file_path, dry=True).as_posix()
         rec['session_path'] = alfio.get_session_path(file_path).as_posix()
         rec['rel_path'] = file_path[len(rec['session_path']):].strip('/')
